@@ -13,14 +13,16 @@ def dictify(s: str):
         if flag not in flags:
             flags.append(flag)
     dict = {}
-    dict["binflags"] = []
+    dict["bin"] = []
+    dict["args"] = []
     for flag in flags:
         flag_indexes =  [f"{i}" for i, x in enumerate(s) if x == flag]
         itc_ini.extend(flag_indexes)
         try:
             if (int(flag_indexes[0]) + 1) <= (len(s) - 1):
                 if s[int(flag_indexes[0]) + 1] in ["True", "False"]:
-                    dict["binflags"].append(flag)
+                    dict["bin"].append(flag)
+                    continue
                 dict[f"{flag}"] = []
                 for flag_index in flag_indexes:
                     dict[f"{flag}"].append(s[int(flag_index) + 1])
@@ -29,9 +31,9 @@ def dictify(s: str):
             continue
         try:
             if len(flag_indexes) == 1 and not s[int(flag_indexes[0]) + 1].startswith('-'):
-                dict["binflags"].append(flag)
+                dict["bin"].append(flag)
         except IndexError:
-            dict["binflags"].append(flag)
+            dict["bin"].append(flag)
 
     itc = [x for x in itc_ini if x not in itc]
     for i in itc:
@@ -40,6 +42,6 @@ def dictify(s: str):
     for flag in flags:
         if flag in s:
             s[s.index(flag)] = ''
-    dict["noflag"] = [x for x in s if x]
+    dict["args"] = [x for x in s if x]
 
     return dict
